@@ -73,7 +73,7 @@
 #'            data=d)
 #' neg.paired(var1=d$control,var2=d$intervention,eil=-1,eiu=1,plot=TRUE)
 #' neg.paired(var1=d$control,var2=d$intervention,eil=-1,eiu=1,normality=FALSE,
-#'            plot=TRUE)
+#'            nboot=10,plot=TRUE)
 #'
 #' \dontrun{
 #' #long format
@@ -394,5 +394,11 @@ print.neg.paired <- function(x, ...) {
   }
 }
 
-
+#wide format
+ID<-rep(1:20)
+control<-rnorm(20)
+intervention<-rnorm(20)
+d<-data.frame(ID, control, intervention)
+head(d)
+neg.paired(var1=control,var2=intervention,eil=-1,eiu=1,plot=TRUE,data=d)
 
